Lightly modified version of the BLE stack, that doesn't bring up a DFUService by default... as we have our own.

Fork of BLE_API by Bluetooth Low Energy

Revision:
254:fb2a891a0d98
Parent:
251:6ce809c972bb
Child:
255:cdb7231f83df
--- a/services/URIBeaconConfigService.h	Fri Dec 12 13:32:24 2014 +0000
+++ b/services/URIBeaconConfigService.h	Fri Dec 12 15:52:48 2014 +0000
@@ -414,7 +414,9 @@
     }
 
 private:
-    static const size_t MAX_SIZEOF_SERVICE_DATA_PAYLOAD = 18; /* Uri Data must be between 0 and 18 bytes in length. */
+    static const size_t MAX_SIZEOF_SERVICE_DATA_PAYLOAD = 22; /* Uri Data must be between 0 and 18 bytes in length; and
+                                                               * together with the 4-byte header, the service data must
+                                                               * fit within 22 bytes. */
     static const size_t MAX_SIZE_URI_DATA_CHAR_VALUE    = 48; /* This is chosen arbitrarily. It should be large enough
                                                                * to hold any reasonable uncompressed URI. */